#
# spec file for package ncompress
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ncompress
Version:        5.0
Release:        1.12
Summary:        LZW compression and decompression utilities
License:        SUSE-Public-Domain
Group:          Productivity/Archiving/Compression
URL:            https://github.com/vapier/ncompress
Source:         https://github.com/vapier/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# gzip provides the uncompress tool in /usr/bin
# we don't provide a link here as this conflicts with gzip
Requires:       gzip

%description
The ncompress package contains the "compress" and "uncompress"
utilities which are compatible with the original UNIX compress
utility (.Z file extensions).

Install ncompress if you need compression/decompression utilities
which are compatible with the original UNIX compress utility. gzip is
also able to decompress .Z files, though ncompress will not recognize
.gz files at all.

%prep
%autosetup

%build
export CFLAGS="%{optflags}"
%make_build

%install
install -Dpm 0755 compress \
  %{buildroot}%{_bindir}/compress
install -Dpm 0644 compress.1 \
  %{buildroot}%{_mandir}/man1/compress.1

%check
make %{?_smp_mflags} check

%files
%license UNLICENSE
%doc LZW.INFO README.md
%{_bindir}/compress
%{_mandir}/man1/compress.1%{?ext_man}

%changelog
* Mon Apr 26 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 5.0:
  * New stream for cleanups
  * Drop support for 2.0 output & -C option
  * Improve & fix recursive mode
  * Drop old DEF_ERRNO support
  * Drop DIRENT/SYSDIR config knobs
  * Drop support for REGISTER build knob
  * Drop support for explicit unaligned memory accesses
  * Drop support for dead operating systems
  * Fix Windows access fallback logic
  * Include io.h on Windows
  * Disable "deprecated" API warnings on Windows
  * Add setmode binary for stdin and stdout on Windows
  * Clean up help text a bit
  * Add a standard -k (keep) option
  * Use io.h fallbacks on mingw too
* Thu May 14 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 4.2.4.6:
  * Fix tests under macOS
  * Drop support for NOFUNCDEF
  * Drop old unused MARK & SIZE_INNER_LOOP defines
  * Add chmod/chown stubs for AMIGA/DOS
  * Add a WINDOWS define for disabling chmod/chown
  * Simplify LSTAT checking
  * Disable utime usage on AMIGA/DOS/WINDOWS
  * Add a fallback for access() for DOS & WINDOWS
  * Disable unistd.h include on DOS & WINDOWS
  * Disable chmod/chown/utime for mingw builds
  * Add xxx->_xxx redirects on WINDOWS for filesystem funcs
  * Add support for Windows in Travis
  * Add PREFIX conformance, add option to only install main program by Eli Schwartz
  * Don't strip binaries by default by Eli Schwartz
  * Set the mandir to use $(PREFIX)/share/man by default by Eli Schwartz
  * Do not set exit_code when an error is ignored by Petr Kubat
  * Use default CFLAGS when using GNU make
  * Fix typos in Makefile.def
  * Tweak Changes style for better markdown integration
* Thu Dec  5 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 4.2.4.5:
  * New homepage https://github.com/vapier/ncompress
  * Switch to intmax_t for nlink_t fields when printing
  * Make builds more reproducible by dropping datestamps
  * Fix integer overflow in maxmaxcode computation by Jakub Wilk
  * Don't leak file descriptor in error cases by Pavel Raiskup
  * Drop 8.3 filename checks for old DOS/Windows
  * Change signal ifdef logic to the signal names
  * Fix -Werror=parentheses errors with newer compilers
  * Define LSTAT=1 in modern builds by default
  * Change pathnames to be dynamic to avoid hardcoded 1k limit
  * Add a standard -h (help) option
  * Change version output to go to stdout
  * Start a testsuite!
  * Add support for -- to halt option parsing
  * Add a uncompress(1) link to compress(1)
- Drop all upstreamed patches:
  * ncompress-2GB.patch
  * ncompress-4.2.4.4-drop-datestamp.patch
  * ncompress-4.2.4.4-filenamelen.patch
  * ncompress-4.2.4.4-lfs2.patch
  * ncompress-4.2.4-endians.patch
  * ncompress-4.2.4-make.patch
* Thu Dec  6 2018 Martin Pluskal <mpluskal@suse.com>
- Really use optflags
* Sun Jul 23 2017 bwiedemann@suse.com
- Add ncompress-4.2.4.4-drop-datestamp.patch to drop compile date
  to fix build-compare (boo#1047218)
- Use make Makefile to avoid build time race
* Fri May 26 2017 jengelh@inai.de
- Reword description
* Sun May 21 2017 meissner@suse.com
- fixed endian define (bsc#1040046)
* Sun Oct 23 2016 mpluskal@suse.com
- Small spec file cleanups:
  * Use pretty name for archive
  * Drop alpha and itanium specific parts
  * Run spec-cleaner on spec file
* Thu Nov 26 2015 opensuse@dstoecker.de
- stop to provide uncompress tool and require gzip instead
* Wed Nov 11 2015 opensuse@dstoecker.de
- fix for Leap 42.1
* Sat Sep  8 2007 Dirk Stöcker <opensuse@dstoecker.de> 4.2.4
- adapted for openSUSE build service
  Sun Oct 01 2006 Jesse Keating 4.2.4
- rebuilt for unwind info generation, broken in gcc-4.1.1-21
  Tue Sep 19 2006 Peter Vrabec 4.2.4
- fix endian problem (#207001)
  Thu Aug 10 2006 Peter Vrabec 4.2.4
- fix bss buffer underflow CVE-2006-1168 (#201919)
  Fri Apr 21 2006 Peter Vrabec 4.2.4
- fix problems with compressing zero-sized files (#189215, #189216)
  Fri Feb 10 2006 Jesse Keating 4.2.4
- bump again for double-long bug on ppc(64)
  Tue Feb 07 2006 Jesse Keating 4.2.4
- rebuilt for new gcc4.1 snapshot and glibc changes
  Thu Sep 22 2005 Peter Vrabec 4.2.4
- compress zero-sized files when -f is used(#167615)
  Tue Oct 05 2004 Than Ngo 4.2.4
- permit files > 2GB to be compressed (#126775).
  Thu Dec 12 2002 Tim Powers 4.2.4
- rebuild on all arches
  Wed Jun 19 2002 Trond Eivind Glomsrød 4.2.4
- Don't strip when installing
  Mon Nov 26 2001 Trond Eivind Glomsrød 4.2.4
- Rebuild, to fix problem with broken man page (#56654)
  Wed Nov 21 2001 Trond Eivind Glomsrød 4.2.4
- Exit, don't segfault, when given too long filenames
  Sat Jun 09 2001 Florian La Roche 4.2.4
- s390x change
  Tue May  8 2001 Trond Eivind Glomsrød
- Make it support large files (structs, stats, opens and of course:
  _don't use signed longs for file size before and after compression_.)
  This should fix #39470
  Thu Apr 26 2001 Florian La Roche
- add s390x, patch from Oliver Paukstadt
  Mon Nov 13 2000 Oliver Paukstadt
- add s390 to the bigendian arch list
  Thu Aug 17 2000 Trond Eivind Glomsrød
- change category to Applications/File, to match
  gzip and bzip2
- rename the spec file to ncompress.spec
- add ppc to the bigendian arch list
  Tue Jun 13 2000 Trond Eivind Glomsrød
- update URL
- use %%%%{_mandir}
  Wed May  5 2000 Bill Nottingham
- fix build for ia64
  Mon Feb  7 2000 Bill Nottingham
- handle compressed manpages
  Sun Mar 21 1999 Cristian Gafton
- auto rebuild in the new build environment (release 14)
  Thu Aug 13 1998 Jeff Johnson
- build root
  Mon Apr 27 1998 Prospector System
- translations modified for de, fr, tr
  Wed Oct 21 1997 Cristian Gafton
- fixed the spec file
  Mon Jun 02 1997 Erik Troan
- built against glibc
